pageNums

# XMLRésuméLibrary: User Guide

organization | Element Reference | pager

## Name

pageNums — One or more page numbers or ranges

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `pageNums` element specifies one or more page numbers or ranges of page numbers, and is used in citing a publication.

### Parents

`pageNums` may be contained in these elements: `pub`

## Examples

    <pub>
      <artTitle>Ancient Mayan Anthropology</artTitle>
      <bookTitle>Nature</bookTitle>
      <pageNums>13-54</pageNums>
    </pub>

    <pub>
      <artTitle>The New Fad: Bottle Cap Collecting</artTitle>
      <bookTitle>Time Magazine</bookTitle>
      <pageNums>14</pageNums>
    </pub>

organization | Element Reference | pager